@@ -4,7 +4,13 @@ use warnings;
 use strict;
 
 use Carp qw(croak);
-use IPC::System::Simple qw(capturex systemx);
+use IPC::System::Simple qw(capturex systemx runx);
+use Capture::Tiny qw(capture_merged);
+
+# TODO: considering we use Capture::Tiny, maybe drop IPC::System::Simple
+#       and move to Capture::Tiny altogether (note that this means 
+#       checking exit status and raising exceptions). Or at least
+#       drop all capturex.
 
 =head1 NAME
 
@@ -12,11 +18,11 @@ Passwd::Keyring::OSXKeychain - Password storage implementation based on OSX/Keyc
 
 =head1 VERSION
 
-Version 0.1006
+Version 0.20
 
 =cut
 
-our $VERSION = '0.1006';
+our $VERSION = '0.20';
 
 =head1 WARNING
 
@@ -165,17 +171,18 @@ If such password can not be found, returns undef.
 sub get_password {
     my ($self, $user_name, $realm) = @_;
 
-    my $reply = capturex(
-        [0, 44],   # Legal exit values. Some CpanTesters report 44 on password not found
-        $self->_make_sys_args(
-            "-q", # quiet
-            "find-generic-password",
-            "-a", $user_name,
-            "-s", $realm,
-            "-D", $self->{group}, # "kind", can be used to match so let be
-            "-g", # display the password
-        ));
-
+    my $reply = capture_merged  {
+        runx(
+            [0, 44],   # Legal exit values. Some CpanTesters report 44 on password not found
+            $self->_make_sys_args(
+                "-q", # quiet
+                "find-generic-password",
+                "-a", $user_name,
+                "-s", $realm,
+                "-D", $self->{group}, # "kind", can be used to match so let be
+                "-g", # display the password
+               ));
+    };
     return _parse_password_from_find_output($reply);
 }
 
